import React, { useRef } from 'react';
import { StyleSheet, View, Text, TextInput } from 'react-native';
import { Theme } from '../Styles/theme';
import Icon from '../Icon';
const Search = props => {
    const $input = useRef(null);
    const { value, shape = 'round', textAlign = 'left', color = Theme.colorTextParagraph, borderColor = Theme.colorIconBase, placeholder, placeholderColor = Theme.colorTextPlaceholder, backgroundColor = 'transparent', showClear = true, searchText = '搜索', searchTextColor = Theme.colorLink, showSearchText = true, textInputProps = {}, style = {}, onChange, onSearch, onClear, } = props;
    const onSearchText = () => {
        onSearch && onSearch(value);
    };
    const onClearText = () => {
        onChange('');
        onClear && onClear();
    };
    return (React.createElement(View, { style: [styles.searchContainer, style] },
        React.createElement(View, { style: [styles.search, shape === 'round' && styles.round, { backgroundColor, borderColor }] },
            React.createElement(Icon, { name: "search", size: 22, color: placeholderColor }),
            React.createElement(TextInput, Object.assign({ ref: $input, style: [styles.searchInput, { color }], placeholder: placeholder, textAlign: textAlign, placeholderTextColor: placeholderColor, returnKeyType: "search", blurOnSubmit: true, enablesReturnKeyAutomatically: true, multiline: false }, textInputProps, { value: value, onChangeText: onChange, onSubmitEditing: onSearchText })),
            showClear && !!value && (React.createElement(Icon, { name: "close-circle", size: 20, color: Theme.colorTextPlaceholder, onPress: onClearText }))),
        showSearchText && (React.createElement(View, { style: styles.searchTextWrap },
            React.createElement(Text, { style: [styles.searchText, { color: searchTextColor }], onPress: () => {
                    onSearchText();
                    $input.current?.blur();
                } }, searchText)))));
};
const styles = StyleSheet.create({
    searchContainer: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
    },
    search: {
        flex: 1,
        flexDirection: 'row',
        alignItems: 'center',
        borderWidth: 0.5,
        borderRadius: 4,
        paddingHorizontal: 6,
    },
    round: {
        borderRadius: 16,
    },
    searchInput: {
        flex: 1,
        padding: 0,
        marginLeft: 4,
        height: 30,
        fontSize: 14,
    },
    searchTextWrap: {
        marginLeft: 8,
    },
    searchText: {
        fontSize: 18,
    },
});
export default Search;
